aboutsummaryrefslogtreecommitdiffstats
path: root/chilbert/BigBitVec.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'chilbert/BigBitVec.hpp')
-rw-r--r--chilbert/BigBitVec.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/chilbert/BigBitVec.hpp b/chilbert/BigBitVec.hpp
index d25d1c8..c395b05 100644
--- a/chilbert/BigBitVec.hpp
+++ b/chilbert/BigBitVec.hpp
@@ -182,8 +182,8 @@ public:
return *this;
}
- /// Toggle the value of the `index`th bit
- CBigBitVec& toggle(const int index)
+ /// Flip the value of the `index`th bit
+ CBigBitVec& flip(const int index)
{
assert(index >= 0 && index < size());
int r, b;